@@ -176,7 +176,7 @@ class iSQL:
         Run a query by storing it into a temporary .sql file
         and return the result as a list of tuples.
         """
-        tmpdir = data_path.joinpath('tmp')
+        tmpdir = data_dir.joinpath('tmp')
         tmpdir.mkdir(exist_ok=True)
         filename = tmpdir.joinpath(f"tmp{uuid.uuid4()}.sql")
 
